@@ -39,26 +39,34 @@ dictionary_sugar = function(dict, .key, ...) {
   }
 
   # pass args to constructor and remove them
-  cargs = get_constructor_formals(obj$value)
-  ii = is.na(names2(dots)) | names2(dots) %in% cargs
+  constructor_args = get_constructor_formals(obj$value)
+  ii = is.na(names2(dots)) | names2(dots) %in% constructor_args
   instance = assert_r6(dictionary_initialize_item(.key, obj, dots[ii]))
   dots = dots[!ii]
 
 
   # set params in ParamSet
   if (length(dots) && exists("param_set", envir = instance, inherits = FALSE)) {
-    ii = names(dots) %in% instance$param_set$ids()
+    param_ids = instance$param_set$ids()
+    ii = names(dots) %in% param_ids
     if (any(ii)) {
       instance$param_set$values = insert_named(instance$param_set$values, dots[ii])
       dots = dots[!ii]
     }
+  } else {
+    param_ids = character()
   }
 
   # remaining args go into fields
   if (length(dots)) {
     ndots = names(dots)
     for (i in seq_along(dots)) {
-      instance[[ndots[i]]] = dots[[i]]
+      nn = ndots[[i]]
+      if (!exists(nn, envir = instance, inherits = FALSE)) {
+        stopf("Cannot set argument '%s' for '%s' (not a constructor argument, not a parameter, not a field.%s",
+          nn, class(instance)[1L], did_you_mean(nn, c(constructor_args, param_ids, fields(obj$value))))
+      }
+      instance[[nn]] = dots[[i]]
     }
   }
 
@@ -83,3 +91,7 @@ get_constructor_formals = function(x) {
 
   return(character())
 }
+
+fields = function(x) {
+  c(setdiff(names(x$public_methods), c("initialize", "clone", "print", "format")), names(x$active))
+}
