@@ -5,6 +5,7 @@
 #' @importFrom R6 R6Class
 "_PACKAGE"
 
-.onLoad = function(libname, pkgname) { # nocov start
+.onLoad = function(libname, pkgname) {
+  # nocov start
   backports::import(pkgname)
 } # nocov end
